pub enum HandshakeOutput {
InitSDPOffer,
RequestSDPAnswer(SignalingPayload),
AcceptSDPAnswer(SignalingPayload),
Connected,
Close,
}Expand description
Commands emitted by the handshake FSM for the driver to execute.
Variants
InitSDPOffer
Initiate creating, applying and sending offer to other peer (to joiner)
RequestSDPAnswer(SignalingPayload)
Initiate creating, applying and sending answer to other peer (to host)
AcceptSDPAnswer(SignalingPayload)
Apply received answer from other peer (from joiner)
Connected
Register connect with other peer
Close
Close connection