HandshakeFSM

Struct HandshakeFSM 

pub struct HandshakeFSM { /* private fields */ }
Per-peer handshake state machine.

One HandshakeFSM exists per remote peer in crate::MeshNodeFSM. Dispatches to a Host or Joiner strategy depending on which side initiates the SDP exchange.

Implementations

Source

impl HandshakeFSM

pub fn new(strategy: HandshakeStrategy) -> Self

pub fn host() -> Self

Host created in relay flow, knows its joiner from the initiation

pub fn joiner() -> Self

pub fn state(&self) -> &HandshakeState

Get current handshake stat

pub fn strategy(&self) -> &HandshakeStrategy

pub fn process( &mut self, input: HandshakeInput, ) -> Result<Option<HandshakeOutput>>

Process handshake input and generate handshake output