pub enum HandshakeState {
Idle,
CreatingOffer,
WaitingForAnswer,
CreatingAnswer,
WaitingForDataChannel,
Connected,
Closed,
}Expand description
Handshake-level state of the client handshake FSM.
Variants
Idle
Peer created but negotiation hasn’t started yet
CreatingOffer
Host is creating offer
WaitingForAnswer
Host sent offer to joiner and is waiting for other peer answer
CreatingAnswer
Joiner is creating answer
WaitingForDataChannel
Joiner sent answer and waiting to establish data channel with host
Connected
Peer has established connection with other peer
Closed
Connection is closed